from typing import Any, Callable, ClassVar, Dict, Iterable, Iterator, List, Tuple

from typing import overload
import numpy
Checked: QtCheckState
Degrees: AngleUnits
Equal: ComparisonOperators
GreaterThan: ComparisonOperators
HtmlFormat: InfoStringFormat
LessThan: ComparisonOperators
Manual: InitializationType
NEW_EXISTS: RenameErrorCodes
NotEqual: ComparisonOperators
OLD_DOES_NOT_EXIST: RenameErrorCodes
PartiallyChecked: QtCheckState
Radians: AngleUnits
RandomWithRange: InitializationType
SAME_PATH: RenameErrorCodes
SUCCESS: RenameErrorCodes
Unchecked: QtCheckState
Unknown: ComparisonOperators
UnknownFormat: InfoStringFormat

class ASCIIWizardData:
    def __init__(self) -> None: ...
    def isEmpty(self) -> bool: ...
    def updateDataArrayPath(self, renamePath: Tuple[DataArrayPath,DataArrayPath]) -> None: ...

class AbstractComparison:
    UnionOperator: int
    def __init__(self, *args, **kwargs) -> None: ...

class AbstractFilter:
    Cancel: bool
    DataContainerArray: DataContainerArray
    Enabled: bool
    InPreflight: bool
    PipelineIndex: int
    def __init__(self, *args, **kwargs) -> None: ...
    def clearErrorCode(self) -> None: ...
    def clearWarningCode(self) -> None: ...
    def connectObserver(self, arg0: Observer) -> None: ...
    def disconnectObserver(self, arg0: Observer) -> None: ...
    def execute(self) -> None: ...
    def generateHtmlSummary(self) -> str: ...
    def notifyProgressMessage(self, progress: int, messageText: str) -> None: ...
    def notifyStatusMessage(self, messageText: str) -> None: ...
    def preflight(self) -> None: ...
    def setDataContainerArray(self, arg0: DataContainerArray) -> None: ...
    def setErrorCondition(self, code: int, messageText: str) -> None: ...
    def setWarningCondition(self, code: int, messageText: str) -> None: ...
    @property
    def CompiledLibraryName(self) -> str: ...
    @property
    def ErrorCode(self) -> int: ...
    @property
    def FilterVersion(self) -> str: ...
    @property
    def GroupName(self) -> str: ...
    @property
    def HumanLabel(self) -> str: ...
    @property
    def NameOfClass(self) -> str: ...
    @property
    def SubGroupName(self) -> str: ...
    @property
    def WarningCode(self) -> int: ...

class AngleUnits:
    __members__: ClassVar[dict] = ...  # read-only
    Degrees: ClassVar[AngleUnits] = ...
    Radians: ClassVar[AngleUnits] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class ArrayCalculator(AbstractFilter):
    CalculatedArray: DataArrayPath
    InfixEquation: str
    ScalarType: ScalarTypes
    SelectedAttributeMatrix: DataArrayPath
    Units: AngleUnits
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class AttributeMatrix:
    class Category:
        __members__: ClassVar[dict] = ...  # read-only
        Any: ClassVar[AttributeMatrix.Category] = ...
        Element: ClassVar[AttributeMatrix.Category] = ...
        Ensemble: ClassVar[AttributeMatrix.Category] = ...
        Feature: ClassVar[AttributeMatrix.Category] = ...
        Unknown: ClassVar[AttributeMatrix.Category] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class Type:
        __members__: ClassVar[dict] = ...  # read-only
        Any: ClassVar[AttributeMatrix.Type] = ...
        Cell: ClassVar[AttributeMatrix.Type] = ...
        CellEnsemble: ClassVar[AttributeMatrix.Type] = ...
        CellFeature: ClassVar[AttributeMatrix.Type] = ...
        Edge: ClassVar[AttributeMatrix.Type] = ...
        EdgeEnsemble: ClassVar[AttributeMatrix.Type] = ...
        EdgeFeature: ClassVar[AttributeMatrix.Type] = ...
        Face: ClassVar[AttributeMatrix.Type] = ...
        FaceEnsemble: ClassVar[AttributeMatrix.Type] = ...
        FaceFeature: ClassVar[AttributeMatrix.Type] = ...
        Generic: ClassVar[AttributeMatrix.Type] = ...
        MetaData: ClassVar[AttributeMatrix.Type] = ...
        Unknown: ClassVar[AttributeMatrix.Type] = ...
        Vertex: ClassVar[AttributeMatrix.Type] = ...
        VertexEnsemble: ClassVar[AttributeMatrix.Type] = ...
        VertexFeature: ClassVar[AttributeMatrix.Type] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...
    Name: str
    TupleDimensions: VectorUInt64
    def __init__(self, arg0: VectorUInt64, arg1: str, arg2: AttributeMatrix.Type) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...
    def addOrReplaceAttributeArray(self, Data: IDataArray) -> bool: ...
    def doesAttributeArrayExist(self, Name: str) -> bool: ...
    @overload
    def getAttributeArray(self, Name: str) -> IDataArray: ...
    @overload
    def getAttributeArray(self, Path: DataArrayPath) -> IDataArray: ...
    def insertOrAssign(self, IDataArrayShPtrType: IDataArray) -> bool: ...
    def removeAttributeArray(self, Name: str) -> IDataArray: ...
    def renameAttributeArray(self, OldName: str, NewName: str, OverWrite: bool) -> RenameErrorCodes: ...
    def __contains__(self, arg0: str) -> bool: ...
    def __getitem__(self, arg0: str) -> IDataArray: ...
    def __iter__(self) -> Iterator: ...
    def __len__(self) -> int: ...
    @property
    def size(self) -> int: ...

class AttributeMatrixCreationFilterParameter(FilterParameter):
    class RequirementType:
        dcGeometryTypes: List[IGeometry.Type]
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: List[IGeometry.Type]) -> None: ...
    def __init__(self, arg0: str, arg1: str, arg2: DataArrayPath, arg3: FilterParameter.Category, arg4: Callable[[DataArrayPath],None], arg5: Callable[[],DataArrayPath], arg6: AttributeMatrixCreationFilterParameter.RequirementType, arg7: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class AttributeMatrixProxy:
    AMType: AttributeMatrix.Type
    DataArrays: Any
    Flag: int
    Name: str
    def __init__(self) -> None: ...
    def getDataArrayProxy(self, name: str) -> DataArrayProxy: ...

class AttributeMatrixSelectionFilterParameter(FilterParameter):
    class RequirementType:
        amTypes: List[AttributeMatrix.Type]
        dcGeometryTypes: List[IGeometry.Type]
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: List[IGeometry.Type], arg1: List[AttributeMatrix.Type]) -> None: ...
    def __init__(self, arg0: str, arg1: str, arg2: DataArrayPath, arg3: FilterParameter.Category, arg4: Callable[[DataArrayPath],None], arg5: Callable[[],DataArrayPath], arg6: AttributeMatrixSelectionFilterParameter.RequirementType, arg7: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class AxisAngleFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: AxisAngleInput, arg3: FilterParameter.Category, arg4: Callable[[AxisAngleInput],None], arg5: Callable[[],AxisAngleInput], arg6: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class AxisAngleInput:
    def __init__(self, arg0: float, arg1: float, arg2: float, arg3: float) -> None: ...

class BoolArray(IDataArray):
    dtype: ClassVar[dtype] = ...  # read-only
    name: str
    @overload
    def __init__(self, num_elements: int, name: str, init_value: bool) -> None: ...
    @overload
    def __init__(self, num_elements: int, c_dims: VectorUInt64, name: str, init_value: bool) -> None: ...
    @overload
    def __init__(self, data: numpy.ndarray[bool], name: str) -> None: ...
    def npview(self) -> numpy.ndarray[bool]: ...
    def __getitem__(self, arg0: int) -> bool: ...
    def __iter__(self) -> Iterator: ...
    def __len__(self) -> int: ...
    def __setitem__(self, arg0: int, arg1: bool) -> None: ...
    @property
    def cdims(self) -> tuple: ...
    @property
    def size(self) -> int: ...
    @property
    def tuples(self) -> int: ...

class BooleanFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: bool, arg3: FilterParameter.Category, arg4: Callable[[bool],None], arg5: Callable[[],bool], arg6: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class Breakpoint(AbstractFilter):
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class CalculatorFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: str, arg3: FilterParameter.Category, arg4: Callable[[str],None], arg5: Callable[[],str], arg6: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class ChoiceFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: int, arg3: FilterParameter.Category, arg4: Callable[[int],None], arg5: Callable[[],int], arg6: List[str], arg7: bool, arg8: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class CombineAttributeArrays(AbstractFilter):
    NormalizeData: bool
    SelectedDataArrayPaths: List[DataArrayPath]
    StackedDataArrayName: str
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class CombineAttributeMatrices(AbstractFilter):
    CombinedAttributeMatrixName: str
    FirstAttributeMatrixPath: DataArrayPath
    FirstIndexArrayPath: DataArrayPath
    NewIndexArrayName: str
    SecondAttributeMatrixPath: DataArrayPath
    SecondIndexArrayPath: DataArrayPath
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class ComparisonInput_t:
    attributeArrayName: str
    attributeMatrixName: str
    compOperator: int
    compValue: float
    dataContainerName: str
    def __init__(self, *args, **kwargs) -> None: ...

class ComparisonInputs:
    def __init__(self) -> None: ...
    @overload
    def addInput(self, dataContainerName: str, attributeMatrixName: str, arrayName: str, compOperator: int, compValue: float) -> None: ...
    @overload
    def addInput(self, input: ComparisonInput_t) -> None: ...
    def size(self) -> int: ...
    @property
    def Inputs(self) -> Any: ...

class ComparisonInputsAdvanced:
    AttributeMatrixName: str
    DataContainerName: str
    def __init__(self) -> None: ...
    @overload
    def addInput(self, unionOperator: int, arrayName: str, compOperator: int, compValue: float) -> None: ...
    @overload
    def addInput(self, unionOperator: int, invertComparison: bool, comparisons: List[AbstractComparison]) -> None: ...
    @overload
    def addInput(self, input: AbstractComparison) -> None: ...
    def size(self) -> int: ...
    @property
    def Inputs(self) -> List[AbstractComparison]: ...

class ComparisonOperators:
    __members__: ClassVar[dict] = ...  # read-only
    Equal: ClassVar[ComparisonOperators] = ...
    GreaterThan: ClassVar[ComparisonOperators] = ...
    LessThan: ClassVar[ComparisonOperators] = ...
    NotEqual: ClassVar[ComparisonOperators] = ...
    Unknown: ClassVar[ComparisonOperators] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class ComparisonSelectionAdvancedFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: ComparisonInputsAdvanced, arg3: FilterParameter.Category, arg4: Callable[[ComparisonInputsAdvanced],None], arg5: Callable[[],ComparisonInputsAdvanced], arg6: List[str], arg7: bool, arg8: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class ComparisonSelectionFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: ComparisonInputs, arg3: FilterParameter.Category, arg4: Callable[[ComparisonInputs],None], arg5: Callable[[],ComparisonInputs], arg6: List[str], arg7: bool, arg8: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class ComparisonSet(AbstractComparison):
    Comparisons: List[AbstractComparison]
    InvertComparison: bool
    UnionOperator: int
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...
    def addComparison(self, comparison: AbstractComparison) -> None: ...
    def insertComparison(self, index: int, comparison: AbstractComparison) -> None: ...

class ComparisonValue(AbstractComparison):
    AttributeArrayName: str
    CompOperator: int
    CompValue: float
    ParentSet: ComparisonSet
    UnionOperator: int
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class ConditionalSetValue(AbstractFilter):
    ConditionalArrayPath: DataArrayPath
    ReplaceValue: float
    SelectedArrayPath: DataArrayPath
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class ConstrainedDoubleFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: float, arg3: float, arg4: float, arg5: FilterParameter.Category, arg6: Callable[[float],None], arg7: Callable[[],float], arg8: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class ConstrainedIntFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: int, arg3: int, arg4: int, arg5: FilterParameter.Category, arg6: Callable[[int],None], arg7: Callable[[],int], arg8: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class ConvertColorToGrayScale(AbstractFilter):
    ColorChannel: int
    ColorWeights: FloatVec3
    ConversionAlgorithm: int
    CreateNewAttributeMatrix: bool
    InputDataArrayVector: List[DataArrayPath]
    OutputArrayPrefix: str
    OutputAttributeMatrixName: str
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class ConvertData(AbstractFilter):
    OutputArrayName: str
    ScalarType: NumericTypes
    SelectedCellArrayPath: DataArrayPath
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class CopyFeatureArrayToElementArray(AbstractFilter):
    CreatedArrayName: str
    FeatureIdsArrayPath: DataArrayPath
    SelectedFeatureArrayPath: DataArrayPath
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class CopyObject(AbstractFilter):
    AttributeArrayToCopy: DataArrayPath
    AttributeMatrixToCopy: DataArrayPath
    CopiedObjectName: str
    DataContainerToCopy: DataArrayPath
    ObjectToCopy: int
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class CreateAttributeMatrix(AbstractFilter):
    AttributeMatrixType: int
    CreatedAttributeMatrix: DataArrayPath
    TupleDimensions: DynamicTableData
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class CreateDataArray(AbstractFilter):
    InitializationRange: Tuple[float,float]
    InitializationType: int
    InitializationValue: str
    NewArray: DataArrayPath
    NumberOfComponents: int
    ScalarType: ScalarTypes
    StartingIndexValue: int
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class CreateDataContainer(AbstractFilter):
    DataContainerName: DataArrayPath
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class CreateFeatureArrayFromElementArray(AbstractFilter):
    CellFeatureAttributeMatrixName: DataArrayPath
    CreatedArrayName: str
    FeatureIdsArrayPath: DataArrayPath
    SelectedCellArrayPath: DataArrayPath
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class CreateGeometry(AbstractFilter):
    ArrayHandling: bool
    DataContainerName: DataArrayPath
    Dimensions: IntVec3
    EdgeAttributeMatrixName: str
    FaceAttributeMatrixName0: str
    FaceAttributeMatrixName1: str
    GeometryType: int
    ImageCellAttributeMatrixName: str
    Origin: FloatVec3
    RectGridCellAttributeMatrixName: str
    SharedEdgeListArrayPath: DataArrayPath
    SharedQuadListArrayPath: DataArrayPath
    SharedTetListArrayPath: DataArrayPath
    SharedTriListArrayPath: DataArrayPath
    SharedVertexListArrayPath0: DataArrayPath
    SharedVertexListArrayPath1: DataArrayPath
    SharedVertexListArrayPath2: DataArrayPath
    SharedVertexListArrayPath3: DataArrayPath
    SharedVertexListArrayPath4: DataArrayPath
    Spacing: FloatVec3
    TetCellAttributeMatrixName: str
    TreatWarningsAsErrors: bool
    VertexAttributeMatrixName0: str
    VertexAttributeMatrixName1: str
    VertexAttributeMatrixName2: str
    VertexAttributeMatrixName3: str
    VertexAttributeMatrixName4: str
    XBoundsArrayPath: DataArrayPath
    YBoundsArrayPath: DataArrayPath
    ZBoundsArrayPath: DataArrayPath
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class CreateGridMontage(AbstractFilter):
    DataContainerNameList: List[str]
    GridSelection: DataContainerGrid
    MontageName: str
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class CreateImageGeometry(AbstractFilter):
    Dimensions: IntVec3
    Origin: FloatVec3
    SelectedDataContainer: DataArrayPath
    Spacing: FloatVec3
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class CreateStringArray(AbstractFilter):
    InitializationValue: str
    NewArray: DataArrayPath
    NumberOfComponents: int
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class CropVertexGeometry(AbstractFilter):
    CroppedDataContainerName: DataArrayPath
    DataContainerName: DataArrayPath
    XMax: float
    XMin: float
    YMax: float
    YMin: float
    ZMax: float
    ZMin: float
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class CrystalStructure:
    __members__: ClassVar[dict] = ...  # read-only
    Cubic_High: ClassVar[CrystalStructure] = ...
    Cubic_Low: ClassVar[CrystalStructure] = ...
    Hexagonal_High: ClassVar[CrystalStructure] = ...
    Hexagonal_Low: ClassVar[CrystalStructure] = ...
    Monoclinic: ClassVar[CrystalStructure] = ...
    OrthoRhombic: ClassVar[CrystalStructure] = ...
    Tetragonal_High: ClassVar[CrystalStructure] = ...
    Tetragonal_Low: ClassVar[CrystalStructure] = ...
    Triclinic: ClassVar[CrystalStructure] = ...
    Trigonal_High: ClassVar[CrystalStructure] = ...
    Trigonal_Low: ClassVar[CrystalStructure] = ...
    UnknownCrystalStructure: ClassVar[CrystalStructure] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class DataArrayCreationFilterParameter(FilterParameter):
    class RequirementType:
        amTypes: List[AttributeMatrix.Type]
        dcGeometryTypes: List[IGeometry.Type]
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: List[IGeometry.Type], arg1: List[AttributeMatrix.Type]) -> None: ...
    def __init__(self, arg0: str, arg1: str, arg2: DataArrayPath, arg3: FilterParameter.Category, arg4: Callable[[DataArrayPath],None], arg5: Callable[[],DataArrayPath], arg6: DataArrayCreationFilterParameter.RequirementType, arg7: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class DataArrayPath:
    AttributeMatrixName: str
    DataArrayName: str
    DataContainerName: str
    @overload
    def __init__(self, arg0: str, arg1: str, arg2: str) -> None: ...
    @overload
    def __init__(self, arg0: str) -> None: ...
    def isEmpty(self) -> bool: ...
    def isValid(self) -> bool: ...
    def update(self, dcName: str, amName: str, daName: str) -> None: ...

class DataArrayProxy:
    CompDims: VectorUInt64
    Flag: int
    Name: str
    Path: str
    TupleDims: VectorUInt64
    def __init__(self) -> None: ...

class DataArraySelectionFilterParameter(FilterParameter):
    class RequirementType:
        amTypes: List[AttributeMatrix.Type]
        componentDimensions: List[VectorUInt64]
        daTypes: List[str]
        dcGeometryTypes: List[IGeometry.Type]
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: List[IGeometry.Type], arg1: List[AttributeMatrix.Type], arg2: List[str], arg3: List[VectorUInt64]) -> None: ...
    def __init__(self, arg0: str, arg1: str, arg2: DataArrayPath, arg3: FilterParameter.Category, arg4: Callable[[DataArrayPath],None], arg5: Callable[[],DataArrayPath], arg6: DataArraySelectionFilterParameter.RequirementType, arg7: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class DataContainer:
    Geometry: IGeometry
    Name: str
    @overload
    def __init__(self, arg0: str) -> None: ...
    @overload
    def __init__(self, arg0: DataArrayPath) -> None: ...
    def addOrReplaceAttributeMatrix(self, AttributeMatrix: AttributeMatrix) -> bool: ...
    @overload
    def createNonPrereqAttributeMatrix(self, filter, path: DataArrayPath, tDims: VectorUInt64, amType: AttributeMatrix.Type, id: int = ...) -> AttributeMatrix: ...
    @overload
    def createNonPrereqAttributeMatrix(self, filter, attributeMatrixName: str, tDims: VectorUInt64, amType: AttributeMatrix.Type, id: int = ...) -> AttributeMatrix: ...
    def doesAttributeMatrixExist(self, Name: str) -> bool: ...
    @overload
    def getAttributeMatrix(self, Name: str) -> AttributeMatrix: ...
    @overload
    def getAttributeMatrix(self, Path: DataArrayPath) -> AttributeMatrix: ...
    def getInfoString(self, InfoStringFormat: InfoStringFormat) -> str: ...
    def insertOrAssign(self, AttributeMatrix: AttributeMatrix) -> bool: ...
    def removeAttributeMatrix(self, Name: str) -> AttributeMatrix: ...
    def renameAttributeMatrix(self, OldName: str, NewName: str, OverWrite: bool) -> bool: ...
    def setGeometry(self, Geometry: IGeometry) -> None: ...
    def __contains__(self, arg0: str) -> bool: ...
    def __getitem__(self, arg0: str) -> AttributeMatrix: ...
    def __iter__(self) -> Iterator: ...
    def __len__(self) -> int: ...
    @property
    def size(self) -> int: ...

class DataContainerArray:
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...
    def addOrReplaceDataContainer(self, DataContainer: DataContainer) -> bool: ...
    def clearDataContainers(self) -> None: ...
    def createNonPrereqArrayFromPath(self, filter, type: NumericTypes, path: DataArrayPath, initValue: object, compDims: VectorUInt64, property: str = ..., id: int = ...) -> object: ...
    @overload
    def createNonPrereqDataContainer(self, filter, dataContainerName: str, id: int = ...) -> DataContainer: ...
    @overload
    def createNonPrereqDataContainer(self, filter, dap: DataArrayPath, id: int = ...) -> DataContainer: ...
    def doesAttributeArrayExist(self, DataArrayPath: DataArrayPath) -> bool: ...
    def doesAttributeMatrixExist(self, DataArrayPath: DataArrayPath) -> bool: ...
    @overload
    def doesDataContainerExist(self, Name: str) -> bool: ...
    @overload
    def doesDataContainerExist(self, Path: DataArrayPath) -> bool: ...
    def duplicateDataContainer(self, OldName: str, NewName: str) -> None: ...
    def getAttributeMatrix(self, DataArrayPath: DataArrayPath) -> AttributeMatrix: ...
    @overload
    def getDataContainer(self, Name: str) -> DataContainer: ...
    @overload
    def getDataContainer(self, Path: DataArrayPath) -> DataContainer: ...
    def getNumDataContainers(self) -> int: ...
    def insertOrAssign(self, DataContainer: DataContainer) -> bool: ...
    def removeDataContainer(self, Name: str) -> DataContainer: ...
    @overload
    def renameDataContainer(self, OldName: str, NewName: str) -> bool: ...
    @overload
    def renameDataContainer(self, OldPath: DataArrayPath, NewPath: DataArrayPath) -> bool: ...
    def __contains__(self, arg0: str) -> bool: ...
    def __getitem__(self, arg0: str) -> DataContainer: ...
    def __iter__(self) -> Iterator: ...
    def __len__(self) -> int: ...
    @property
    def size(self) -> int: ...

class DataContainerArrayProxy:
    DataContainers: Dict[str,DataContainerProxy]
    def __init__(self) -> None: ...
    def getDataContainerProxy(self, name: str) -> DataContainerProxy: ...

class DataContainerArrayProxyFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: DataContainerArrayProxy, arg3: FilterParameter.Category, arg4: Callable[[DataContainerArrayProxy],None], arg5: Callable[[],DataContainerArrayProxy], arg6: DataContainerArrayProxy, arg7: QtCheckState, arg8: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class DataContainerCreationFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: DataArrayPath, arg3: FilterParameter.Category, arg4: Callable[[DataArrayPath],None], arg5: Callable[[],DataArrayPath], arg6: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class DataContainerGrid:
    @overload
    def __init__(self, arg0: SizeVec3) -> None: ...
    @overload
    def __init__(self, arg0: SizeVec3, arg1: List[str]) -> None: ...

class DataContainerGridSelectionFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: DataContainerGrid, arg3: FilterParameter.Category, arg4: Callable[[DataContainerGrid],None], arg5: Callable[[],DataContainerGrid], arg6: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class DataContainerProxy:
    AttributeMatricies: Dict[str,AttributeMatrixProxy]
    Flag: int
    Name: str
    def __init__(self) -> None: ...
    def getAttributeMatrixProxy(self, name: str) -> AttributeMatrixProxy: ...
    def toggleFlag(self) -> None: ...

class DataContainerReader(AbstractFilter):
    InputFile: str
    InputFileDataContainerArrayProxy: DataContainerArrayProxy
    OverwriteExistingDataContainers: bool
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...
    def readDataContainerArrayStructure(self, path: str) -> DataContainerArrayProxy: ...

class DataContainerReaderFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: str, arg3: FilterParameter.Category, arg4: DataContainerReader, arg5: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class DataContainerSelectionFilterParameter(FilterParameter):
    class RequirementType:
        dcGeometryTypes: List[IGeometry.Type]
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: List[IGeometry.Type]) -> None: ...
    def __init__(self, arg0: str, arg1: str, arg2: DataArrayPath, arg3: FilterParameter.Category, arg4: Callable[[DataArrayPath],None], arg5: Callable[[],DataArrayPath], arg6: DataContainerSelectionFilterParameter.RequirementType, arg7: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class DataContainerWriter(AbstractFilter):
    OutputFile: str
    WriteTimeSeries: bool
    WriteXdmfFile: bool
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class DatasetImportInfoList:
    def __init__(self, arg0: list) -> None: ...

class DateTime:
    def __init__(self, arg0: int, arg1: int, arg2: int, arg3: int) -> None: ...

class DelimiterTypes:
    __members__: ClassVar[dict] = ...  # read-only
    Colon: ClassVar[DelimiterTypes] = ...
    Comma: ClassVar[DelimiterTypes] = ...
    Semicolon: ClassVar[DelimiterTypes] = ...
    Space: ClassVar[DelimiterTypes] = ...
    Tab: ClassVar[DelimiterTypes] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class DoubleArray(IDataArray):
    dtype: ClassVar[dtype] = ...  # read-only
    name: str
    @overload
    def __init__(self, num_elements: int, name: str, init_value: float) -> None: ...
    @overload
    def __init__(self, num_elements: int, c_dims: VectorUInt64, name: str, init_value: float) -> None: ...
    @overload
    def __init__(self, data: numpy.ndarray[numpy.float64], name: str) -> None: ...
    def npview(self) -> numpy.ndarray[numpy.float64]: ...
    def __getitem__(self, arg0: int) -> float: ...
    def __iter__(self) -> Iterator: ...
    def __len__(self) -> int: ...
    def __setitem__(self, arg0: int, arg1: float) -> None: ...
    @property
    def cdims(self) -> tuple: ...
    @property
    def size(self) -> int: ...
    @property
    def tuples(self) -> int: ...

class DoubleFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: float, arg3: FilterParameter.Category, arg4: Callable[[float],None], arg5: Callable[[],float], arg6: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class DynamicChoiceFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: str, arg3: FilterParameter.Category, arg4: Callable[[str],None], arg5: Callable[[],str], arg6: str, arg7: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class DynamicTableData:
    ColHeaders: List[str]
    RowHeaders: List[str]
    TableData: List[VectorDouble]
    def __init__(self, arg0: List[VectorDouble], arg1: List[str], arg2: List[str]) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class DynamicTableFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: DynamicTableData, arg3: FilterParameter.Category, arg4: Callable[[DynamicTableData],None], arg5: Callable[[],DynamicTableData], arg6: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class EdgeGeom(IGeometry):
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...
    def getCoords(self, arg0: int, arg1: float) -> None: ...
    def getEdges(self) -> UInt64Array: ...
    def getNumberOfEdges(self) -> int: ...
    def getNumberOfElements(self) -> int: ...
    def getNumberOfVertices(self) -> int: ...
    def getVertices(self) -> FloatArray: ...
    def setCoords(self, arg0: int, arg1: float) -> None: ...
    def setEdges(self, arg0: UInt64Array) -> None: ...
    def setVertices(self, arg0: FloatArray) -> None: ...

class EmptyFilter(AbstractFilter):
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class EnsembleInfo:
    def __init__(self) -> None: ...
    def addValues(self, arg0: CrystalStructure, arg1: PhaseType, arg2: str) -> None: ...
    def clear(self) -> None: ...
    def getValues(self, arg0: int, arg1: CrystalStructure, arg2: PhaseType, arg3: str) -> None: ...
    def remove(self, arg0: int) -> None: ...

class ExecuteProcess(AbstractFilter):
    Arguments: str
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class ExtractAttributeArraysFromGeometry(AbstractFilter):
    DataContainerName: DataArrayPath
    SharedEdgeListArrayPath: DataArrayPath
    SharedQuadListArrayPath: DataArrayPath
    SharedTetListArrayPath: DataArrayPath
    SharedTriListArrayPath: DataArrayPath
    SharedVertexListArrayPath0: DataArrayPath
    SharedVertexListArrayPath1: DataArrayPath
    SharedVertexListArrayPath2: DataArrayPath
    SharedVertexListArrayPath3: DataArrayPath
    SharedVertexListArrayPath4: DataArrayPath
    XBoundsArrayPath: DataArrayPath
    YBoundsArrayPath: DataArrayPath
    ZBoundsArrayPath: DataArrayPath
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class ExtractComponentAsArray(AbstractFilter):
    CompNumber: int
    NewArrayArrayName: str
    SelectedArrayPath: DataArrayPath
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class ExtractVertexGeometry(AbstractFilter):
    ArrayHandling: int
    IncludedDataArrayPaths: List[DataArrayPath]
    MaskArrayPath: DataArrayPath
    SelectedDataContainerName: DataArrayPath
    UseMask: bool
    VertexDataContainerName: DataArrayPath
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class FeatureCountDecision(AbstractFilter):
    FeatureIdsArrayPath: DataArrayPath
    MaxGrains: int
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class FeatureDataCSVWriter(AbstractFilter):
    CellFeatureAttributeMatrixPath: DataArrayPath
    DelimiterChoice: int
    FeatureDataFile: str
    WriteNeighborListData: bool
    WriteNumFeaturesLine: bool
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class FileListInfoFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: StackFileListInfo, arg3: FilterParameter.Category, arg4: Callable[[StackFileListInfo],None], arg5: Callable[[],StackFileListInfo]) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class FileWriter(AbstractFilter):
    OutputFile: str
    def __init__(self, *args, **kwargs) -> None: ...

class FilterDelegateCpp:
    def __init__(self, *args, **kwargs) -> None: ...
    def notifyProgressMessage(self, arg0: int, arg1: str) -> None: ...
    def notifyStatusMessage(self, arg0: str) -> None: ...
    def setWarningCondition(self, arg0: int, arg1: str) -> None: ...
    @property
    def preflight(self) -> bool: ...

class FilterParameter:
    class Category:
        __members__: ClassVar[dict] = ...  # read-only
        CreatedArray: ClassVar[FilterParameter.Category] = ...
        Parameter: ClassVar[FilterParameter.Category] = ...
        RequiredArray: ClassVar[FilterParameter.Category] = ...
        Uncategorized: ClassVar[FilterParameter.Category] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...
    def __init__(self, *args, **kwargs) -> None: ...

class FilterPipeline:
    CurrentFilter: AbstractFilter
    Name: str
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...
    def addObserver(self, Observer: Observer) -> None: ...
    def clear(self) -> bool: ...
    def clearErrorCode(self) -> None: ...
    def clearWarningCode(self) -> None: ...
    def empty(self) -> bool: ...
    def popBack(self) -> bool: ...
    def popFront(self) -> bool: ...
    def preflightPipeline(self) -> int: ...
    def pushBack(self, AbstractFilter: AbstractFilter) -> bool: ...
    def pushFront(self, AbstractFilter: AbstractFilter) -> bool: ...
    def removeObserver(self, Observer: Observer) -> None: ...
    def run(self) -> DataContainerArray: ...
    def size(self) -> int: ...
    @property
    def ErrorCode(self) -> int: ...
    @property
    def ExecutionResult(self) -> Any: ...
    @property
    def State(self) -> Any: ...
    @property
    def WarningCode(self) -> int: ...

class FindDerivatives(AbstractFilter):
    DerivativesArrayPath: DataArrayPath
    SelectedArrayPath: DataArrayPath
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class Float2ndOrderPolynomial:
    def __init__(self, arg0: float, arg1: float, arg2: float, arg3: float, arg4: float, arg5: float) -> None: ...

class Float3rdOrderPoly:
    def __init__(self, arg0: float, arg1: float, arg2: float, arg3: float, arg4: float, arg5: float, arg6: float, arg7: float, arg8: float, arg9: float) -> None: ...

class Float4thOrderPolynomial:
    def __init__(self, arg0: float, arg1: float, arg2: float, arg3: float, arg4: float, arg5: float, arg6: float, arg7: float, arg8: float, arg9: float, arg10: float, arg11: float, arg12: float, arg13: float, arg14: float) -> None: ...

class FloatArray(IDataArray):
    dtype: ClassVar[dtype] = ...  # read-only
    name: str
    @overload
    def __init__(self, num_elements: int, name: str, init_value: float) -> None: ...
    @overload
    def __init__(self, num_elements: int, c_dims: VectorUInt64, name: str, init_value: float) -> None: ...
    @overload
    def __init__(self, data: numpy.ndarray[numpy.float32], name: str) -> None: ...
    def npview(self) -> numpy.ndarray[numpy.float32]: ...
    def __getitem__(self, arg0: int) -> float: ...
    def __iter__(self) -> Iterator: ...
    def __len__(self) -> int: ...
    def __setitem__(self, arg0: int, arg1: float) -> None: ...
    @property
    def cdims(self) -> tuple: ...
    @property
    def size(self) -> int: ...
    @property
    def tuples(self) -> int: ...

class FloatFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: float, arg3: FilterParameter.Category, arg4: Callable[[float],None], arg5: Callable[[],float], arg6: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class FloatVec2:
    def __init__(self, arg0: list) -> None: ...
    def __getitem__(self, arg0: int) -> float: ...

class FloatVec2FilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: FloatVec2, arg3: FilterParameter.Category, arg4: Callable[[FloatVec2],None], arg5: Callable[[],FloatVec2], arg6: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class FloatVec3:
    def __init__(self, arg0: list) -> None: ...
    def __getitem__(self, arg0: int) -> float: ...

class FloatVec3FilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: FloatVec3, arg3: FilterParameter.Category, arg4: Callable[[FloatVec3],None], arg5: Callable[[],FloatVec3], arg6: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class FloatVec4:
    def __init__(self, arg0: list) -> None: ...
    def __getitem__(self, arg0: int) -> float: ...

class FloatVec6:
    def __init__(self, arg0: list) -> None: ...
    def __getitem__(self, arg0: int) -> float: ...

class FourthOrderPolynomialFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: Float4thOrderPolynomial, arg3: FilterParameter.Category, arg4: Callable[[Float4thOrderPolynomial],None], arg5: Callable[[],Float4thOrderPolynomial], arg6: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class GenerateColorTable(AbstractFilter):
    RgbArrayName: str
    SelectedDataArrayPath: DataArrayPath
    SelectedPresetControlPoints: JsonArray
    SelectedPresetName: str
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class GenerateColorTableFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: str, arg3: FilterParameter.Category, arg4: GenerateColorTable, arg5: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class GenerateTiltSeries(AbstractFilter):
    InputDataArrayPath: DataArrayPath
    OutputPrefix: str
    RotationAxis: int
    RotationLimits: FloatVec3
    Spacing: FloatVec3
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class GenerateVertexCoordinates(AbstractFilter):
    CoordinateArrayPath: DataArrayPath
    SelectedDataContainerName: DataArrayPath
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class IDataArray:
    Name: str
    def __init__(self, *args, **kwargs) -> None: ...
    def getComponentDimensions(self) -> VectorUInt64: ...
    def getNumberOfComponents(self) -> int: ...
    def getNumberOfTuples(self) -> int: ...
    def getTypeAsString(self) -> str: ...

class IGeometry:
    class LengthUnit:
        __members__: ClassVar[dict] = ...  # read-only
        Angstrom: ClassVar[IGeometry.LengthUnit] = ...
        Attometer: ClassVar[IGeometry.LengthUnit] = ...
        Centimeter: ClassVar[IGeometry.LengthUnit] = ...
        Decameter: ClassVar[IGeometry.LengthUnit] = ...
        Decimeter: ClassVar[IGeometry.LengthUnit] = ...
        Exameter: ClassVar[IGeometry.LengthUnit] = ...
        Fathom: ClassVar[IGeometry.LengthUnit] = ...
        Femtometer: ClassVar[IGeometry.LengthUnit] = ...
        Foot: ClassVar[IGeometry.LengthUnit] = ...
        Gigameter: ClassVar[IGeometry.LengthUnit] = ...
        Hectometer: ClassVar[IGeometry.LengthUnit] = ...
        Inch: ClassVar[IGeometry.LengthUnit] = ...
        Kilometer: ClassVar[IGeometry.LengthUnit] = ...
        Megameter: ClassVar[IGeometry.LengthUnit] = ...
        Meter: ClassVar[IGeometry.LengthUnit] = ...
        Micrometer: ClassVar[IGeometry.LengthUnit] = ...
        Mil: ClassVar[IGeometry.LengthUnit] = ...
        Mile: ClassVar[IGeometry.LengthUnit] = ...
        Millimeter: ClassVar[IGeometry.LengthUnit] = ...
        Nanometer: ClassVar[IGeometry.LengthUnit] = ...
        Petameter: ClassVar[IGeometry.LengthUnit] = ...
        Picometer: ClassVar[IGeometry.LengthUnit] = ...
        Terameter: ClassVar[IGeometry.LengthUnit] = ...
        Unknown: ClassVar[IGeometry.LengthUnit] = ...
        Unspecified: ClassVar[IGeometry.LengthUnit] = ...
        Yoctometer: ClassVar[IGeometry.LengthUnit] = ...
        Yottameter: ClassVar[IGeometry.LengthUnit] = ...
        Zeptometer: ClassVar[IGeometry.LengthUnit] = ...
        Zettameter: ClassVar[IGeometry.LengthUnit] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class Type:
        __members__: ClassVar[dict] = ...  # read-only
        Any: ClassVar[IGeometry.Type] = ...
        Edge: ClassVar[IGeometry.Type] = ...
        Hexahedral: ClassVar[IGeometry.Type] = ...
        Image: ClassVar[IGeometry.Type] = ...
        Quad: ClassVar[IGeometry.Type] = ...
        RectGrid: ClassVar[IGeometry.Type] = ...
        Tetrahedral: ClassVar[IGeometry.Type] = ...
        Triangle: ClassVar[IGeometry.Type] = ...
        Unknown: ClassVar[IGeometry.Type] = ...
        Vertex: ClassVar[IGeometry.Type] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...

    class VtkCellType:
        __members__: ClassVar[dict] = ...  # read-only
        Any: ClassVar[IGeometry.VtkCellType] = ...
        Edge: ClassVar[IGeometry.VtkCellType] = ...
        Hexahedral: ClassVar[IGeometry.VtkCellType] = ...
        Image: ClassVar[IGeometry.VtkCellType] = ...
        Quad: ClassVar[IGeometry.VtkCellType] = ...
        RectGrid: ClassVar[IGeometry.VtkCellType] = ...
        Tetrahedral: ClassVar[IGeometry.VtkCellType] = ...
        Triangle: ClassVar[IGeometry.VtkCellType] = ...
        Unknown: ClassVar[IGeometry.VtkCellType] = ...
        Vertex: ClassVar[IGeometry.VtkCellType] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...
    Name: str
    SpatialDimensionality: int
    def __init__(self, *args, **kwargs) -> None: ...
    def addOrReplaceAttributeMatrix(self, Name: str, AttributeMatrix: AttributeMatrix) -> None: ...
    def deepCopy(self, forceNoAllocate: bool) -> IGeometry: ...
    def getAttributeMatrix(self, Name: str) -> AttributeMatrix: ...
    def getGeometryType(self) -> IGeometry.Type: ...
    def getGeometryTypeAsString(self) -> str: ...
    def getInfoString(self, formatType: InfoStringFormat) -> str: ...
    def getUnitDimensionality(self) -> int: ...
    def getXdmfGridType(self) -> int: ...
    def initializeWithZeros(self) -> None: ...
    def removeAttributeMatrix(self, Name: str) -> AttributeMatrix: ...

class IGeometry2D(IGeometry):
    def __init__(self, *args, **kwargs) -> None: ...

class IGeometryGrid(IGeometry):
    def __init__(self, *args, **kwargs) -> None: ...

class IObserver:
    def __init__(self) -> None: ...

class ImageGeom(IGeometryGrid):
    class ErrorType:
        __members__: ClassVar[dict] = ...  # read-only
        IndexOutOfBounds: ClassVar[ImageGeom.ErrorType] = ...
        NoError: ClassVar[ImageGeom.ErrorType] = ...
        XOutOfBoundsHigh: ClassVar[ImageGeom.ErrorType] = ...
        XOutOfBoundsLow: ClassVar[ImageGeom.ErrorType] = ...
        YOutOfBoundsHigh: ClassVar[ImageGeom.ErrorType] = ...
        YOutOfBoundsLow: ClassVar[ImageGeom.ErrorType] = ...
        ZOutOfBoundsHigh: ClassVar[ImageGeom.ErrorType] = ...
        ZOutOfBoundsLow: ClassVar[ImageGeom.ErrorType] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: str) -> None: ...
    def CreateGeometry(self, *args, **kwargs) -> Any: ...
    def New(self, *args, **kwargs) -> Any: ...
    def getBoundingBox(self) -> FloatVec6: ...
    def getDimensions(self) -> SizeVec3: ...
    def getOrigin(self) -> FloatVec3: ...
    def getSpacing(self) -> FloatVec3: ...
    def getXPoints(self) -> int: ...
    def getYPoints(self) -> int: ...
    def getZPoints(self) -> int: ...
    def setDimensions(self, x: int, y: int, z: int) -> None: ...
    def setOrigin(self, x: float, y: float, z: float) -> None: ...
    def setSpacing(self, x: float, y: float, z: float) -> None: ...

class ImportAsciDataArray(AbstractFilter):
    CreatedAttributeArrayPath: DataArrayPath
    Delimiter: int
    InputFile: str
    NumberOfComponents: int
    ScalarType: NumericTypes
    SkipHeaderLines: int
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class ImportHDF5Dataset(AbstractFilter):
    DatasetImportInfoList: DatasetImportInfoList
    HDF5FilePath: str
    SelectedAttributeMatrix: DataArrayPath
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class ImportHDF5DatasetFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: str, arg3: str, arg4: FilterParameter.Category, arg5: ImportHDF5Dataset, arg6: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class InfoStringFormat:
    __members__: ClassVar[dict] = ...  # read-only
    HtmlFormat: ClassVar[InfoStringFormat] = ...
    UnknownFormat: ClassVar[InfoStringFormat] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class InitializationType:
    __members__: ClassVar[dict] = ...  # read-only
    Manual: ClassVar[InitializationType] = ...
    RandomWithRange: ClassVar[InitializationType] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class InitializeData(AbstractFilter):
    CellAttributeMatrixPaths: List[DataArrayPath]
    InitRange: Tuple[float,float]
    InitType: int
    InitValue: float
    InvertData: bool
    Random: bool
    XMax: int
    XMin: int
    YMax: int
    YMin: int
    ZMax: int
    ZMin: int
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class InputFileFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: str, arg3: FilterParameter.Category, arg4: Callable[[str],None], arg5: Callable[[],str], arg6: str, arg7: str, arg8: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class InputPathFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: str, arg3: FilterParameter.Category, arg4: Callable[[str],None], arg5: Callable[[],str], arg6: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class Int16Array(IDataArray):
    dtype: ClassVar[dtype] = ...  # read-only
    name: str
    @overload
    def __init__(self, num_elements: int, name: str, init_value: int) -> None: ...
    @overload
    def __init__(self, num_elements: int, c_dims: VectorUInt64, name: str, init_value: int) -> None: ...
    @overload
    def __init__(self, data: numpy.ndarray[numpy.int16], name: str) -> None: ...
    def npview(self) -> numpy.ndarray[numpy.int16]: ...
    def __getitem__(self, arg0: int) -> int: ...
    def __iter__(self) -> Iterator: ...
    def __len__(self) -> int: ...
    def __setitem__(self, arg0: int, arg1: int) -> None: ...
    @property
    def cdims(self) -> tuple: ...
    @property
    def size(self) -> int: ...
    @property
    def tuples(self) -> int: ...

class Int32Array(IDataArray):
    dtype: ClassVar[dtype] = ...  # read-only
    name: str
    @overload
    def __init__(self, num_elements: int, name: str, init_value: int) -> None: ...
    @overload
    def __init__(self, num_elements: int, c_dims: VectorUInt64, name: str, init_value: int) -> None: ...
    @overload
    def __init__(self, data: numpy.ndarray[numpy.int32], name: str) -> None: ...
    def npview(self) -> numpy.ndarray[numpy.int32]: ...
    def __getitem__(self, arg0: int) -> int: ...
    def __iter__(self) -> Iterator: ...
    def __len__(self) -> int: ...
    def __setitem__(self, arg0: int, arg1: int) -> None: ...
    @property
    def cdims(self) -> tuple: ...
    @property
    def size(self) -> int: ...
    @property
    def tuples(self) -> int: ...

class Int64Array(IDataArray):
    dtype: ClassVar[dtype] = ...  # read-only
    name: str
    @overload
    def __init__(self, num_elements: int, name: str, init_value: int) -> None: ...
    @overload
    def __init__(self, num_elements: int, c_dims: VectorUInt64, name: str, init_value: int) -> None: ...
    @overload
    def __init__(self, data: numpy.ndarray[numpy.int64], name: str) -> None: ...
    def npview(self) -> numpy.ndarray[numpy.int64]: ...
    def __getitem__(self, arg0: int) -> int: ...
    def __iter__(self) -> Iterator: ...
    def __len__(self) -> int: ...
    def __setitem__(self, arg0: int, arg1: int) -> None: ...
    @property
    def cdims(self) -> tuple: ...
    @property
    def size(self) -> int: ...
    @property
    def tuples(self) -> int: ...

class Int8Array(IDataArray):
    dtype: ClassVar[dtype] = ...  # read-only
    name: str
    @overload
    def __init__(self, num_elements: int, name: str, init_value: int) -> None: ...
    @overload
    def __init__(self, num_elements: int, c_dims: VectorUInt64, name: str, init_value: int) -> None: ...
    @overload
    def __init__(self, data: numpy.ndarray[numpy.int8], name: str) -> None: ...
    def npview(self) -> numpy.ndarray[numpy.int8]: ...
    def __getitem__(self, arg0: int) -> int: ...
    def __iter__(self) -> Iterator: ...
    def __len__(self) -> int: ...
    def __setitem__(self, arg0: int, arg1: int) -> None: ...
    @property
    def cdims(self) -> tuple: ...
    @property
    def size(self) -> int: ...
    @property
    def tuples(self) -> int: ...

class IntFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: int, arg3: FilterParameter.Category, arg4: Callable[[int],None], arg5: Callable[[],int], arg6: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class IntVec2:
    def __init__(self, arg0: list) -> None: ...
    def __getitem__(self, arg0: int) -> int: ...

class IntVec2FilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: IntVec2, arg3: FilterParameter.Category, arg4: Callable[[IntVec2],None], arg5: Callable[[],IntVec2], arg6: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class IntVec3:
    def __init__(self, arg0: list) -> None: ...
    def __getitem__(self, arg0: int) -> int: ...

class IntVec3FilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: IntVec3, arg3: FilterParameter.Category, arg4: Callable[[IntVec3],None], arg5: Callable[[],IntVec3], arg6: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class IntVec4:
    def __init__(self, arg0: list) -> None: ...
    def __getitem__(self, arg0: int) -> int: ...

class IntVec6:
    def __init__(self, arg0: list) -> None: ...
    def __getitem__(self, arg0: int) -> int: ...

class JsonArray:
    def __init__(self, arg0: list) -> None: ...

class JsonFilterParametersReader:
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...
    def readPipelineFromFile(self, arg0: str, arg1: IObserver) -> FilterPipeline: ...

class JsonFilterParametersWriter:
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...
    def exportPipelineToFile(self, arg0: FilterPipeline, arg1: str, arg2: str, arg3: bool, arg4: IObserver) -> int: ...

class LinkFeatureMapToElementArray(AbstractFilter):
    ActiveArrayName: str
    CellFeatureAttributeMatrixName: str
    SelectedCellArrayPath: DataArrayPath
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class LinkedBooleanFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: bool, arg3: FilterParameter.Category, arg4: Callable[[bool],None], arg5: Callable[[],bool], arg6: List[str], arg7: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class LinkedChoicesFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: int, arg3: FilterParameter.Category, arg4: Callable[[int],None], arg5: Callable[[],int], arg6: List[str], arg7: List[str], arg8: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class LinkedDataContainerSelectionFilterParameter(FilterParameter):
    class RequirementType:
        dcGeometryTypes: List[IGeometry.Type]
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: List[IGeometry.Type]) -> None: ...
    def __init__(self, arg0: str, arg1: str, arg2: DataArrayPath, arg3: FilterParameter.Category, arg4: Callable[[DataArrayPath],None], arg5: Callable[[],DataArrayPath], arg6: LinkedDataContainerSelectionFilterParameter.RequirementType, arg7: List[str], arg8: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class MaskCountDecision(AbstractFilter):
    MaskArrayPath: DataArrayPath
    NumberOfTrues: int
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class MassCreateData(AbstractFilter):
    DataContainerName: DataArrayPath
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class MontageFileListInfo:
    def __init__(self, arg0: int, arg1: int, arg2: int, arg3: int) -> None: ...

class MontageSelection:
    ColEnd: int
    ColStart: int
    Padding: int
    Prefix: str
    RowEnd: int
    RowStart: int
    Suffix: str
    def __init__(self, arg0: str, arg1: str, arg2: int, arg3: int, arg4: int, arg5: int, arg6: int) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class MontageSelectionFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: MontageSelection, arg3: FilterParameter.Category, arg4: Callable[[MontageSelection],None], arg5: Callable[[],MontageSelection], arg6: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class MontageStructureSelectionFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: str, arg3: FilterParameter.Category, arg4: Callable[[str],None], arg5: Callable[[],str], arg6: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class MoveData(AbstractFilter):
    AttributeMatrixDestination: DataArrayPath
    AttributeMatrixSource: DataArrayPath
    DataArraySource: DataArrayPath
    DataContainerDestination: DataArrayPath
    WhatToMove: int
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class MoveMultiData(AbstractFilter):
    AttributeMatrixDestination: DataArrayPath
    AttributeMatrixSources: List[DataArrayPath]
    DataArraySources: List[DataArrayPath]
    DataContainerDestination: DataArrayPath
    WhatToMove: int
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class MultiAttributeMatrixSelectionFilterParameter(FilterParameter):
    class RequirementType:
        amTypes: List[AttributeMatrix.Type]
        componentDimensions: List[VectorUInt64]
        daTypes: List[str]
        dcGeometryTypes: List[IGeometry.Type]
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: List[IGeometry.Type], arg1: List[AttributeMatrix.Type], arg2: List[str], arg3: List[VectorUInt64]) -> None: ...
    def __init__(self, arg0: str, arg1: str, arg2: List[DataArrayPath], arg3: FilterParameter.Category, arg4: Callable[[List[DataArrayPath]],None], arg5: Callable[[],List[DataArrayPath]], arg6: MultiAttributeMatrixSelectionFilterParameter.RequirementType, arg7: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class MultiDataArraySelectionFilterParameter(FilterParameter):
    class RequirementType:
        amTypes: List[AttributeMatrix.Type]
        componentDimensions: List[VectorUInt64]
        daTypes: List[str]
        dcGeometryTypes: List[IGeometry.Type]
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: List[IGeometry.Type], arg1: List[AttributeMatrix.Type], arg2: List[str], arg3: List[VectorUInt64]) -> None: ...
    def __init__(self, arg0: str, arg1: str, arg2: List[DataArrayPath], arg3: FilterParameter.Category, arg4: Callable[[List[DataArrayPath]],None], arg5: Callable[[],List[DataArrayPath]], arg6: MultiDataArraySelectionFilterParameter.RequirementType, arg7: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class MultiDataContainerSelectionFilterParameter(FilterParameter):
    class RequirementType:
        amTypes: List[AttributeMatrix.Type]
        componentDimensions: List[VectorUInt64]
        daTypes: List[str]
        dcGeometryTypes: List[IGeometry.Type]
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: List[IGeometry.Type], arg1: List[AttributeMatrix.Type], arg2: List[str], arg3: List[VectorUInt64]) -> None: ...
    def __init__(self, arg0: str, arg1: str, arg2: List[str], arg3: FilterParameter.Category, arg4: Callable[[List[str]],None], arg5: Callable[[],List[str]], arg6: MultiDataContainerSelectionFilterParameter.RequirementType, arg7: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class MultiInputFileFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: List[str], arg3: FilterParameter.Category, arg4: Callable[[List[str]],None], arg5: Callable[[],List[str]], arg6: str, arg7: str, arg8: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class MultiThresholdObjects(AbstractFilter):
    DestinationArrayName: str
    ScalarType: ScalarTypes
    SelectedThresholds: ComparisonInputs
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class MultiThresholdObjects2(AbstractFilter):
    DestinationArrayName: str
    ScalarType: ScalarTypes
    SelectedThresholds: ComparisonInputsAdvanced
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class NumericTypeFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: NumericTypes, arg3: FilterParameter.Category, arg4: Callable[[NumericTypes],None], arg5: Callable[[],NumericTypes], arg6: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class NumericTypes:
    __members__: ClassVar[dict] = ...  # read-only
    Bool: ClassVar[NumericTypes] = ...
    Double: ClassVar[NumericTypes] = ...
    Float: ClassVar[NumericTypes] = ...
    Int16: ClassVar[NumericTypes] = ...
    Int32: ClassVar[NumericTypes] = ...
    Int64: ClassVar[NumericTypes] = ...
    Int8: ClassVar[NumericTypes] = ...
    SizeT: ClassVar[NumericTypes] = ...
    UInt16: ClassVar[NumericTypes] = ...
    UInt32: ClassVar[NumericTypes] = ...
    UInt64: ClassVar[NumericTypes] = ...
    UInt8: ClassVar[NumericTypes] = ...
    UnknownNumType: ClassVar[NumericTypes] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class Observable:
    def __init__(self, *args, **kwargs) -> None: ...
    def notifyProgressMessage(self, progress: int, messageText: str) -> None: ...
    def notifyProgressMessageWithPrefix(self, progress: int, prefix: str, messageText: str) -> None: ...
    def notifyStatusMessage(self, messageText: str) -> None: ...
    def notifyStatusMessageWithPrefix(self, prefix: str, messageText: str) -> None: ...
    def setErrorCondition(self, code: int, messageText: str) -> None: ...
    def setErrorConditionWithPrefix(self, code: int, prefix: str, messageText: str) -> None: ...
    def setWarningCondition(self, code: int, messageText: str) -> None: ...
    def setWarningConditionWithPrefix(self, code: int, prefix: str, messageText: str) -> None: ...

class Observer(IObserver):
    def __init__(self) -> None: ...

class OutputFileFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: str, arg3: FilterParameter.Category, arg4: Callable[[str],None], arg5: Callable[[],str], arg6: str, arg7: str, arg8: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class OutputPathFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: str, arg3: FilterParameter.Category, arg4: Callable[[str],None], arg5: Callable[[],str], arg6: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class PadImageGeometry(AbstractFilter):
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class ParagraphFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: str, arg3: FilterParameter.Category, arg4: Callable[[str],None], arg5: Callable[[],str], arg6: bool, arg7: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class PhaseType:
    __members__: ClassVar[dict] = ...  # read-only
    Any: ClassVar[PhaseType] = ...
    Boundary: ClassVar[PhaseType] = ...
    Matrix: ClassVar[PhaseType] = ...
    Precipitate: ClassVar[PhaseType] = ...
    Primary: ClassVar[PhaseType] = ...
    Transformation: ClassVar[PhaseType] = ...
    Unknown: ClassVar[PhaseType] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class PipelineAnnotation(AbstractFilter):
    Summary: str
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class PostSlackMessage(AbstractFilter):
    SlackMessage: str
    SlackUrl: str
    SlackUser: str
    WarningsAsError: bool
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class PrecipitateStatsData(StatsData):
    BinStepSize: float
    BoundaryArea: float
    FeatureSizeDistribution: List[FloatArray]
    FeatureSize_DistType: int
    MaxFeatureDiameter: float
    MinFeatureDiameter: float
    PhaseFraction: float
    PrecipBoundaryFraction: float
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...
    def generateBinNumbers(self) -> FloatArray: ...
    def getPhaseType(self) -> PhaseType: ...
    def getStatsType(self) -> str: ...

class PreflightUpdatedValueFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: str, arg3: FilterParameter.Category, arg4: Callable[[],str], arg5: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class PrimaryStatsData(StatsData):
    BinStepSize: float
    BoundaryArea: float
    FeatureSizeDistribution: List[FloatArray]
    FeatureSize_DistType: int
    MaxFeatureDiameter: float
    MinFeatureDiameter: float
    PhaseFraction: float
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...
    def generateBinNumbers(self) -> FloatArray: ...
    def getPhaseType(self) -> PhaseType: ...

class PythonFilter(AbstractFilter):
    def __init__(self, arg0: object) -> None: ...

class QtCheckState:
    __members__: ClassVar[dict] = ...  # read-only
    Checked: ClassVar[QtCheckState] = ...
    PartiallyChecked: ClassVar[QtCheckState] = ...
    Unchecked: ClassVar[QtCheckState] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class QuadGeom(IGeometry2D):
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...
    def getCoords(self, arg0: int, arg1: float) -> None: ...
    def getEdges(self) -> UInt64Array: ...
    def getNumberOfEdges(self) -> int: ...
    def getNumberOfElements(self) -> int: ...
    def getNumberOfQuads(self) -> int: ...
    def getNumberOfVertices(self) -> int: ...
    def getQuads(self) -> UInt64Array: ...
    def getVertices(self) -> FloatArray: ...
    def setCoords(self, arg0: int, arg1: float) -> None: ...
    def setQuads(self, arg0: UInt64Array) -> None: ...
    def setVertices(self, arg0: FloatArray) -> None: ...

class RangeFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: Tuple[float,float], arg3: FilterParameter.Category, arg4: Callable[[Tuple[float,float]],None], arg5: Callable[[],Tuple[float,float]], arg6: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class RawBinaryReader(AbstractFilter):
    CreatedAttributeArrayPath: DataArrayPath
    Endian: int
    InputFile: str
    NumberOfComponents: int
    ScalarType: NumericTypes
    SkipHeaderBytes: int
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class ReadASCIIData(AbstractFilter):
    WizardData: ASCIIWizardData
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class ReadASCIIDataFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: str, arg3: FilterParameter.Category, arg4: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class RemoveArrays(AbstractFilter):
    DataArraysToRemove: DataContainerArrayProxy
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class RemoveComponentFromArray(AbstractFilter):
    CompNumber: int
    NewArrayArrayName: str
    ReducedArrayArrayName: str
    SaveRemovedComponent: bool
    SelectedArrayPath: DataArrayPath
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class RenameAttributeArray(AbstractFilter):
    NewArrayName: str
    SelectedArrayPath: DataArrayPath
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class RenameAttributeMatrix(AbstractFilter):
    NewAttributeMatrix: str
    SelectedAttributeMatrixPath: DataArrayPath
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class RenameDataContainer(AbstractFilter):
    NewDataContainerName: DataArrayPath
    SelectedDataContainerName: DataArrayPath
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class RenameErrorCodes:
    __members__: ClassVar[dict] = ...  # read-only
    NEW_EXISTS: ClassVar[RenameErrorCodes] = ...
    OLD_DOES_NOT_EXIST: ClassVar[RenameErrorCodes] = ...
    SAME_PATH: ClassVar[RenameErrorCodes] = ...
    SUCCESS: ClassVar[RenameErrorCodes] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class ReplaceValueInArray(AbstractFilter):
    RemoveValue: float
    ReplaceValue: float
    SelectedArray: DataArrayPath
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class RequiredZThickness(AbstractFilter):
    DataContainerSelection: DataArrayPath
    NumZVoxels: int
    PreflightCheck: bool
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class RotateSampleRefFrame(AbstractFilter):
    class RotationRepresentation:
        __members__: ClassVar[dict] = ...  # read-only
        AxisAngle: ClassVar[RotateSampleRefFrame.RotationRepresentation] = ...
        RotationMatrix: ClassVar[RotateSampleRefFrame.RotationRepresentation] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __ne__(self, other: object) -> bool: ...
        def __setstate__(self, state: int) -> None: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...
    CellAttributeMatrixPath: DataArrayPath
    RotationAngle: float
    RotationAxis: FloatVec3
    RotationRepresentationChoice: int
    RotationTable: DynamicTableData
    SliceBySlice: bool
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...
    def getRotationRepresentation(self) -> RotateSampleRefFrame.RotationRepresentation: ...
    def isRotationRepresentationValid(self, value: int) -> bool: ...
    def setRotationRepresentation(self, value: RotateSampleRefFrame.RotationRepresentation) -> None: ...

class SIMPLH5DataReader:
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...
    def closeFile(self) -> bool: ...
    def openFile(self, filePath: str) -> bool: ...
    def readDataContainerArrayStructure(self, SIMPLH5DataReaderRequirements: SIMPLH5DataReaderRequirements, err: int) -> DataContainerArrayProxy: ...

class SIMPLH5DataReaderRequirements:
    def __init__(self, *args, **kwargs) -> None: ...

class ScalarTypeFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: ScalarTypes, arg3: FilterParameter.Category, arg4: Callable[[ScalarTypes],None], arg5: Callable[[],ScalarTypes], arg6: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class ScalarTypes:
    __members__: ClassVar[dict] = ...  # read-only
    Bool: ClassVar[ScalarTypes] = ...
    Double: ClassVar[ScalarTypes] = ...
    Float: ClassVar[ScalarTypes] = ...
    Int16: ClassVar[ScalarTypes] = ...
    Int32: ClassVar[ScalarTypes] = ...
    Int64: ClassVar[ScalarTypes] = ...
    Int8: ClassVar[ScalarTypes] = ...
    UInt16: ClassVar[ScalarTypes] = ...
    UInt32: ClassVar[ScalarTypes] = ...
    UInt64: ClassVar[ScalarTypes] = ...
    UInt8: ClassVar[ScalarTypes] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class ScaleVolume(AbstractFilter):
    ApplyToSurfaceMesh: bool
    ApplyToVoxelVolume: bool
    DataContainerName: DataArrayPath
    ScaleFactor: FloatVec3
    SurfaceDataContainerName: DataArrayPath
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class SecondOrderPolynomialFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: Float2ndOrderPolynomial, arg3: FilterParameter.Category, arg4: Callable[[Float2ndOrderPolynomial],None], arg5: Callable[[],Float2ndOrderPolynomial], arg6: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class SeparatorFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: FilterParameter.Category) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class SetOriginResolutionImageGeom(AbstractFilter):
    ChangeOrigin: bool
    ChangeResolution: bool
    DataContainerName: DataArrayPath
    Origin: FloatVec3
    Spacing: FloatVec3
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class ShapeType:
    __members__: ClassVar[dict] = ...  # read-only
    Any: ClassVar[ShapeType] = ...
    CubeOctahedron: ClassVar[ShapeType] = ...
    CylinderA: ClassVar[ShapeType] = ...
    CylinderB: ClassVar[ShapeType] = ...
    CylinderC: ClassVar[ShapeType] = ...
    Ellipsoid: ClassVar[ShapeType] = ...
    ShapeTypeEnd: ClassVar[ShapeType] = ...
    SuperEllipsoid: ClassVar[ShapeType] = ...
    Unknown: ClassVar[ShapeType] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class ShapeTypeSelectionFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: List[ShapeType], arg3: FilterParameter.Category, arg4: Callable[[List[ShapeType]],None], arg5: Callable[[],List[ShapeType]], arg6: str, arg7: str, arg8: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class SizeVec2:
    def __init__(self, arg0: list) -> None: ...
    def __getitem__(self, arg0: int) -> int: ...

class SizeVec3:
    def __init__(self, arg0: list) -> None: ...
    def __getitem__(self, arg0: int) -> int: ...

class SizeVec4:
    def __init__(self, arg0: list) -> None: ...
    def __getitem__(self, arg0: int) -> int: ...

class SplitAttributeArray(AbstractFilter):
    InputArrayPath: DataArrayPath
    SplitArraysSuffix: str
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class StackFileListInfo:
    EndIndex: int
    FileExtension: str
    FilePrefix: str
    FileSuffix: str
    IncrementIndex: int
    InputPath: str
    Ordering: int
    PaddingDigits: int
    StartIndex: int
    @overload
    def __init__(self, arg0: str, arg1: int, arg2: int, arg3: int) -> None: ...
    @overload
    def __init__(self, arg0: int, arg1: int, arg2: int, arg3: int, arg4: int, arg5: str, arg6: str, arg7: str, arg8: str) -> None: ...

class StatsData:
    PhaseFraction: float
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...
    def getPhaseType(self) -> PhaseType: ...
    def getStatsType(self) -> str: ...

class StatsDataArray(IDataArray):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: int, arg1: str, arg2: bool) -> None: ...
    @overload
    def __init__(self, arg0: int, arg1: int, arg2: int, arg3: str, arg4: bool) -> None: ...
    @overload
    def __init__(self, arg0: int, arg1: VectorUInt64, arg2: str, arg3: bool) -> None: ...
    @overload
    def __init__(self, arg0: int, arg1: VectorUInt64, arg2: str, arg3: bool) -> None: ...
    @overload
    def __init__(self, arg0: VectorUInt64, arg1: VectorUInt64, arg2: str, arg3: bool) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...
    @overload
    def fillArrayWithNewStatsData(self, n: int, phase_types: PhaseType) -> None: ...
    @overload
    def fillArrayWithNewStatsData(self, n: int, phase_types: int) -> None: ...
    def getStatsData(self, index: int) -> StatsData: ...
    def setStatsData(self, index: int, statsData: StatsData) -> None: ...

class StringDataArray(IDataArray):
    Name: str
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: int, arg1: str, arg2: bool) -> None: ...
    @overload
    def __init__(self, arg0: int, arg1: VectorUInt64, arg2: str, arg3: bool) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...
    def getNumberOfTuples(self) -> int: ...
    def getSize(self) -> int: ...
    def getValue(self, i: int) -> str: ...
    def setValue(self, i: int, value: str) -> None: ...

class StringFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: str, arg3: FilterParameter.Category, arg4: Callable[[str],None], arg5: Callable[[],str], arg6: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class StringSet:
    def __init__(self, arg0: set) -> None: ...

class ThirdOrderPolynomialFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: Float3rdOrderPoly, arg3: FilterParameter.Category, arg4: Callable[[Float3rdOrderPoly],None], arg5: Callable[[],Float3rdOrderPoly], arg6: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class TriangleGeom(IGeometry2D):
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...
    def getCoords(self, vertId: int, coords: float) -> None: ...
    def getEdges(self) -> UInt64Array: ...
    def getNumberOfEdges(self) -> int: ...
    def getNumberOfVertices(self) -> int: ...
    def getVertices(self) -> FloatArray: ...
    def setCoords(self, vertId: int, coords: float) -> None: ...
    def setVertices(self, vertices: FloatArray) -> None: ...

class UInt16Array(IDataArray):
    dtype: ClassVar[dtype] = ...  # read-only
    name: str
    @overload
    def __init__(self, num_elements: int, name: str, init_value: int) -> None: ...
    @overload
    def __init__(self, num_elements: int, c_dims: VectorUInt64, name: str, init_value: int) -> None: ...
    @overload
    def __init__(self, data: numpy.ndarray[numpy.uint16], name: str) -> None: ...
    def npview(self) -> numpy.ndarray[numpy.uint16]: ...
    def __getitem__(self, arg0: int) -> int: ...
    def __iter__(self) -> Iterator: ...
    def __len__(self) -> int: ...
    def __setitem__(self, arg0: int, arg1: int) -> None: ...
    @property
    def cdims(self) -> tuple: ...
    @property
    def size(self) -> int: ...
    @property
    def tuples(self) -> int: ...

class UInt32Array(IDataArray):
    dtype: ClassVar[dtype] = ...  # read-only
    name: str
    @overload
    def __init__(self, num_elements: int, name: str, init_value: int) -> None: ...
    @overload
    def __init__(self, num_elements: int, c_dims: VectorUInt64, name: str, init_value: int) -> None: ...
    @overload
    def __init__(self, data: numpy.ndarray[numpy.uint32], name: str) -> None: ...
    def npview(self) -> numpy.ndarray[numpy.uint32]: ...
    def __getitem__(self, arg0: int) -> int: ...
    def __iter__(self) -> Iterator: ...
    def __len__(self) -> int: ...
    def __setitem__(self, arg0: int, arg1: int) -> None: ...
    @property
    def cdims(self) -> tuple: ...
    @property
    def size(self) -> int: ...
    @property
    def tuples(self) -> int: ...

class UInt64Array(IDataArray):
    dtype: ClassVar[dtype] = ...  # read-only
    name: str
    @overload
    def __init__(self, num_elements: int, name: str, init_value: int) -> None: ...
    @overload
    def __init__(self, num_elements: int, c_dims: VectorUInt64, name: str, init_value: int) -> None: ...
    @overload
    def __init__(self, data: numpy.ndarray[numpy.uint64], name: str) -> None: ...
    def npview(self) -> numpy.ndarray[numpy.uint64]: ...
    def __getitem__(self, arg0: int) -> int: ...
    def __iter__(self) -> Iterator: ...
    def __len__(self) -> int: ...
    def __setitem__(self, arg0: int, arg1: int) -> None: ...
    @property
    def cdims(self) -> tuple: ...
    @property
    def size(self) -> int: ...
    @property
    def tuples(self) -> int: ...

class UInt64FilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: int, arg3: FilterParameter.Category, arg4: Callable[[int],None], arg5: Callable[[],int], arg6: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class UInt8Array(IDataArray):
    dtype: ClassVar[dtype] = ...  # read-only
    name: str
    @overload
    def __init__(self, num_elements: int, name: str, init_value: int) -> None: ...
    @overload
    def __init__(self, num_elements: int, c_dims: VectorUInt64, name: str, init_value: int) -> None: ...
    @overload
    def __init__(self, data: numpy.ndarray[numpy.uint8], name: str) -> None: ...
    def npview(self) -> numpy.ndarray[numpy.uint8]: ...
    def __getitem__(self, arg0: int) -> int: ...
    def __iter__(self) -> Iterator: ...
    def __len__(self) -> int: ...
    def __setitem__(self, arg0: int, arg1: int) -> None: ...
    @property
    def cdims(self) -> tuple: ...
    @property
    def size(self) -> int: ...
    @property
    def tuples(self) -> int: ...

class UnknownFilterParameter(FilterParameter):
    def __init__(self, arg0: str, arg1: str, arg2: str, arg3: FilterParameter.Category, arg4: VectorInt32) -> None: ...
    def Create(self, *args, **kwargs) -> Any: ...

class VectorDouble:
    __hash__: ClassVar[None] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: VectorDouble) -> None: ...
    @overload
    def __init__(self, arg0: Iterable) -> None: ...
    def append(self, x: float) -> None: ...
    def clear(self) -> None: ...
    def count(self, x: float) -> int: ...
    @overload
    def extend(self, L: VectorDouble) -> None: ...
    @overload
    def extend(self, L: Iterable) -> None: ...
    def insert(self, i: int, x: float) -> None: ...
    @overload
    def pop(self) -> float: ...
    @overload
    def pop(self, i: int) -> float: ...
    def remove(self, x: float) -> None: ...
    def __bool__(self) -> bool: ...
    def __contains__(self, x: float) -> bool: ...
    @overload
    def __delitem__(self, arg0: int) -> None: ...
    @overload
    def __delitem__(self, arg0: slice) -> None: ...
    def __eq__(self, arg0: VectorDouble) -> bool: ...
    @overload
    def __getitem__(self, s: slice) -> VectorDouble: ...
    @overload
    def __getitem__(self, arg0: int) -> float: ...
    def __iter__(self) -> Iterator: ...
    def __len__(self) -> int: ...
    def __ne__(self, arg0: VectorDouble) -> bool: ...
    @overload
    def __setitem__(self, arg0: int, arg1: float) -> None: ...
    @overload
    def __setitem__(self, arg0: slice, arg1: VectorDouble) -> None: ...

class VectorFloat:
    __hash__: ClassVar[None] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: VectorFloat) -> None: ...
    @overload
    def __init__(self, arg0: Iterable) -> None: ...
    def append(self, x: float) -> None: ...
    def clear(self) -> None: ...
    def count(self, x: float) -> int: ...
    @overload
    def extend(self, L: VectorFloat) -> None: ...
    @overload
    def extend(self, L: Iterable) -> None: ...
    def insert(self, i: int, x: float) -> None: ...
    @overload
    def pop(self) -> float: ...
    @overload
    def pop(self, i: int) -> float: ...
    def remove(self, x: float) -> None: ...
    def __bool__(self) -> bool: ...
    def __contains__(self, x: float) -> bool: ...
    @overload
    def __delitem__(self, arg0: int) -> None: ...
    @overload
    def __delitem__(self, arg0: slice) -> None: ...
    def __eq__(self, arg0: VectorFloat) -> bool: ...
    @overload
    def __getitem__(self, s: slice) -> VectorFloat: ...
    @overload
    def __getitem__(self, arg0: int) -> float: ...
    def __iter__(self) -> Iterator: ...
    def __len__(self) -> int: ...
    def __ne__(self, arg0: VectorFloat) -> bool: ...
    @overload
    def __setitem__(self, arg0: int, arg1: float) -> None: ...
    @overload
    def __setitem__(self, arg0: slice, arg1: VectorFloat) -> None: ...

class VectorInt16:
    __hash__: ClassVar[None] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: VectorInt16) -> None: ...
    @overload
    def __init__(self, arg0: Iterable) -> None: ...
    def append(self, x: int) -> None: ...
    def clear(self) -> None: ...
    def count(self, x: int) -> int: ...
    @overload
    def extend(self, L: VectorInt16) -> None: ...
    @overload
    def extend(self, L: Iterable) -> None: ...
    def insert(self, i: int, x: int) -> None: ...
    @overload
    def pop(self) -> int: ...
    @overload
    def pop(self, i: int) -> int: ...
    def remove(self, x: int) -> None: ...
    def __bool__(self) -> bool: ...
    def __contains__(self, x: int) -> bool: ...
    @overload
    def __delitem__(self, arg0: int) -> None: ...
    @overload
    def __delitem__(self, arg0: slice) -> None: ...
    def __eq__(self, arg0: VectorInt16) -> bool: ...
    @overload
    def __getitem__(self, s: slice) -> VectorInt16: ...
    @overload
    def __getitem__(self, arg0: int) -> int: ...
    def __iter__(self) -> Iterator: ...
    def __len__(self) -> int: ...
    def __ne__(self, arg0: VectorInt16) -> bool: ...
    @overload
    def __setitem__(self, arg0: int, arg1: int) -> None: ...
    @overload
    def __setitem__(self, arg0: slice, arg1: VectorInt16) -> None: ...

class VectorInt32:
    __hash__: ClassVar[None] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: VectorInt32) -> None: ...
    @overload
    def __init__(self, arg0: Iterable) -> None: ...
    def append(self, x: int) -> None: ...
    def clear(self) -> None: ...
    def count(self, x: int) -> int: ...
    @overload
    def extend(self, L: VectorInt32) -> None: ...
    @overload
    def extend(self, L: Iterable) -> None: ...
    def insert(self, i: int, x: int) -> None: ...
    @overload
    def pop(self) -> int: ...
    @overload
    def pop(self, i: int) -> int: ...
    def remove(self, x: int) -> None: ...
    def __bool__(self) -> bool: ...
    def __contains__(self, x: int) -> bool: ...
    @overload
    def __delitem__(self, arg0: int) -> None: ...
    @overload
    def __delitem__(self, arg0: slice) -> None: ...
    def __eq__(self, arg0: VectorInt32) -> bool: ...
    @overload
    def __getitem__(self, s: slice) -> VectorInt32: ...
    @overload
    def __getitem__(self, arg0: int) -> int: ...
    def __iter__(self) -> Iterator: ...
    def __len__(self) -> int: ...
    def __ne__(self, arg0: VectorInt32) -> bool: ...
    @overload
    def __setitem__(self, arg0: int, arg1: int) -> None: ...
    @overload
    def __setitem__(self, arg0: slice, arg1: VectorInt32) -> None: ...

class VectorInt64:
    __hash__: ClassVar[None] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: VectorInt64) -> None: ...
    @overload
    def __init__(self, arg0: Iterable) -> None: ...
    def append(self, x: int) -> None: ...
    def clear(self) -> None: ...
    def count(self, x: int) -> int: ...
    @overload
    def extend(self, L: VectorInt64) -> None: ...
    @overload
    def extend(self, L: Iterable) -> None: ...
    def insert(self, i: int, x: int) -> None: ...
    @overload
    def pop(self) -> int: ...
    @overload
    def pop(self, i: int) -> int: ...
    def remove(self, x: int) -> None: ...
    def __bool__(self) -> bool: ...
    def __contains__(self, x: int) -> bool: ...
    @overload
    def __delitem__(self, arg0: int) -> None: ...
    @overload
    def __delitem__(self, arg0: slice) -> None: ...
    def __eq__(self, arg0: VectorInt64) -> bool: ...
    @overload
    def __getitem__(self, s: slice) -> VectorInt64: ...
    @overload
    def __getitem__(self, arg0: int) -> int: ...
    def __iter__(self) -> Iterator: ...
    def __len__(self) -> int: ...
    def __ne__(self, arg0: VectorInt64) -> bool: ...
    @overload
    def __setitem__(self, arg0: int, arg1: int) -> None: ...
    @overload
    def __setitem__(self, arg0: slice, arg1: VectorInt64) -> None: ...

class VectorInt8:
    __hash__: ClassVar[None] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: VectorInt8) -> None: ...
    @overload
    def __init__(self, arg0: Iterable) -> None: ...
    def append(self, x: int) -> None: ...
    def clear(self) -> None: ...
    def count(self, x: int) -> int: ...
    @overload
    def extend(self, L: VectorInt8) -> None: ...
    @overload
    def extend(self, L: Iterable) -> None: ...
    def insert(self, i: int, x: int) -> None: ...
    @overload
    def pop(self) -> int: ...
    @overload
    def pop(self, i: int) -> int: ...
    def remove(self, x: int) -> None: ...
    def __bool__(self) -> bool: ...
    def __contains__(self, x: int) -> bool: ...
    @overload
    def __delitem__(self, arg0: int) -> None: ...
    @overload
    def __delitem__(self, arg0: slice) -> None: ...
    def __eq__(self, arg0: VectorInt8) -> bool: ...
    @overload
    def __getitem__(self, s: slice) -> VectorInt8: ...
    @overload
    def __getitem__(self, arg0: int) -> int: ...
    def __iter__(self) -> Iterator: ...
    def __len__(self) -> int: ...
    def __ne__(self, arg0: VectorInt8) -> bool: ...
    @overload
    def __setitem__(self, arg0: int, arg1: int) -> None: ...
    @overload
    def __setitem__(self, arg0: slice, arg1: VectorInt8) -> None: ...

class VectorSizeT:
    __hash__: ClassVar[None] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: VectorUInt64) -> None: ...
    @overload
    def __init__(self, arg0: Iterable) -> None: ...
    def append(self, x: int) -> None: ...
    def clear(self) -> None: ...
    def count(self, x: int) -> int: ...
    @overload
    def extend(self, L: VectorUInt64) -> None: ...
    @overload
    def extend(self, L: Iterable) -> None: ...
    def insert(self, i: int, x: int) -> None: ...
    @overload
    def pop(self) -> int: ...
    @overload
    def pop(self, i: int) -> int: ...
    def remove(self, x: int) -> None: ...
    def __bool__(self) -> bool: ...
    def __contains__(self, x: int) -> bool: ...
    @overload
    def __delitem__(self, arg0: int) -> None: ...
    @overload
    def __delitem__(self, arg0: slice) -> None: ...
    def __eq__(self, arg0: VectorUInt64) -> bool: ...
    @overload
    def __getitem__(self, s: slice) -> VectorUInt64: ...
    @overload
    def __getitem__(self, arg0: int) -> int: ...
    def __iter__(self) -> Iterator: ...
    def __len__(self) -> int: ...
    def __ne__(self, arg0: VectorUInt64) -> bool: ...
    @overload
    def __setitem__(self, arg0: int, arg1: int) -> None: ...
    @overload
    def __setitem__(self, arg0: slice, arg1: VectorUInt64) -> None: ...

class VectorUInt16:
    __hash__: ClassVar[None] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: VectorUInt16) -> None: ...
    @overload
    def __init__(self, arg0: Iterable) -> None: ...
    def append(self, x: int) -> None: ...
    def clear(self) -> None: ...
    def count(self, x: int) -> int: ...
    @overload
    def extend(self, L: VectorUInt16) -> None: ...
    @overload
    def extend(self, L: Iterable) -> None: ...
    def insert(self, i: int, x: int) -> None: ...
    @overload
    def pop(self) -> int: ...
    @overload
    def pop(self, i: int) -> int: ...
    def remove(self, x: int) -> None: ...
    def __bool__(self) -> bool: ...
    def __contains__(self, x: int) -> bool: ...
    @overload
    def __delitem__(self, arg0: int) -> None: ...
    @overload
    def __delitem__(self, arg0: slice) -> None: ...
    def __eq__(self, arg0: VectorUInt16) -> bool: ...
    @overload
    def __getitem__(self, s: slice) -> VectorUInt16: ...
    @overload
    def __getitem__(self, arg0: int) -> int: ...
    def __iter__(self) -> Iterator: ...
    def __len__(self) -> int: ...
    def __ne__(self, arg0: VectorUInt16) -> bool: ...
    @overload
    def __setitem__(self, arg0: int, arg1: int) -> None: ...
    @overload
    def __setitem__(self, arg0: slice, arg1: VectorUInt16) -> None: ...

class VectorUInt32:
    __hash__: ClassVar[None] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: VectorUInt32) -> None: ...
    @overload
    def __init__(self, arg0: Iterable) -> None: ...
    def append(self, x: int) -> None: ...
    def clear(self) -> None: ...
    def count(self, x: int) -> int: ...
    @overload
    def extend(self, L: VectorUInt32) -> None: ...
    @overload
    def extend(self, L: Iterable) -> None: ...
    def insert(self, i: int, x: int) -> None: ...
    @overload
    def pop(self) -> int: ...
    @overload
    def pop(self, i: int) -> int: ...
    def remove(self, x: int) -> None: ...
    def __bool__(self) -> bool: ...
    def __contains__(self, x: int) -> bool: ...
    @overload
    def __delitem__(self, arg0: int) -> None: ...
    @overload
    def __delitem__(self, arg0: slice) -> None: ...
    def __eq__(self, arg0: VectorUInt32) -> bool: ...
    @overload
    def __getitem__(self, s: slice) -> VectorUInt32: ...
    @overload
    def __getitem__(self, arg0: int) -> int: ...
    def __iter__(self) -> Iterator: ...
    def __len__(self) -> int: ...
    def __ne__(self, arg0: VectorUInt32) -> bool: ...
    @overload
    def __setitem__(self, arg0: int, arg1: int) -> None: ...
    @overload
    def __setitem__(self, arg0: slice, arg1: VectorUInt32) -> None: ...

class VectorUInt64:
    __hash__: ClassVar[None] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: VectorUInt64) -> None: ...
    @overload
    def __init__(self, arg0: Iterable) -> None: ...
    def append(self, x: int) -> None: ...
    def clear(self) -> None: ...
    def count(self, x: int) -> int: ...
    @overload
    def extend(self, L: VectorUInt64) -> None: ...
    @overload
    def extend(self, L: Iterable) -> None: ...
    def insert(self, i: int, x: int) -> None: ...
    @overload
    def pop(self) -> int: ...
    @overload
    def pop(self, i: int) -> int: ...
    def remove(self, x: int) -> None: ...
    def __bool__(self) -> bool: ...
    def __contains__(self, x: int) -> bool: ...
    @overload
    def __delitem__(self, arg0: int) -> None: ...
    @overload
    def __delitem__(self, arg0: slice) -> None: ...
    def __eq__(self, arg0: VectorUInt64) -> bool: ...
    @overload
    def __getitem__(self, s: slice) -> VectorUInt64: ...
    @overload
    def __getitem__(self, arg0: int) -> int: ...
    def __iter__(self) -> Iterator: ...
    def __len__(self) -> int: ...
    def __ne__(self, arg0: VectorUInt64) -> bool: ...
    @overload
    def __setitem__(self, arg0: int, arg1: int) -> None: ...
    @overload
    def __setitem__(self, arg0: slice, arg1: VectorUInt64) -> None: ...

class VectorUInt8:
    __hash__: ClassVar[None] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: VectorUInt8) -> None: ...
    @overload
    def __init__(self, arg0: Iterable) -> None: ...
    def append(self, x: int) -> None: ...
    def clear(self) -> None: ...
    def count(self, x: int) -> int: ...
    @overload
    def extend(self, L: VectorUInt8) -> None: ...
    @overload
    def extend(self, L: Iterable) -> None: ...
    def insert(self, i: int, x: int) -> None: ...
    @overload
    def pop(self) -> int: ...
    @overload
    def pop(self, i: int) -> int: ...
    def remove(self, x: int) -> None: ...
    def __bool__(self) -> bool: ...
    def __contains__(self, x: int) -> bool: ...
    @overload
    def __delitem__(self, arg0: int) -> None: ...
    @overload
    def __delitem__(self, arg0: slice) -> None: ...
    def __eq__(self, arg0: VectorUInt8) -> bool: ...
    @overload
    def __getitem__(self, s: slice) -> VectorUInt8: ...
    @overload
    def __getitem__(self, arg0: int) -> int: ...
    def __iter__(self) -> Iterator: ...
    def __len__(self) -> int: ...
    def __ne__(self, arg0: VectorUInt8) -> bool: ...
    @overload
    def __setitem__(self, arg0: int, arg1: int) -> None: ...
    @overload
    def __setitem__(self, arg0: slice, arg1: VectorUInt8) -> None: ...

class VertexGeom(IGeometry):
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...
    def getCoords(self, arg0: int, arg1: float) -> None: ...
    def getNumberOfElements(self) -> int: ...
    def getNumberOfVertices(self) -> int: ...
    def getVertices(self) -> FloatArray: ...
    def setCoords(self, arg0: int, arg1: float) -> None: ...
    def setVertices(self, arg0: FloatArray) -> None: ...

class WriteASCIIData(AbstractFilter):
    Delimiter: int
    FileExtension: str
    MaxValPerLine: int
    OutputFilePath: str
    OutputPath: str
    OutputStyle: int
    SelectedDataArrayPaths: List[DataArrayPath]
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

class WriteTriangleGeometry(AbstractFilter):
    DataContainerSelection: DataArrayPath
    OutputNodesFile: str
    OutputTrianglesFile: str
    def __init__(self) -> None: ...
    def New(self, *args, **kwargs) -> Any: ...

def clearPythonFilters() -> None: ...
def registerPythonFilter(arg0: object) -> None: ...
def unregisterPythonFilter(arg0: str) -> bool: ...
